# Tez: a simple pytorch trainer

**NOTE: Currently, we are not accepting any pull requests! All PRs will be closed. If you want a feature or something doesn't work, please create an issue.**

tez (तेज़ / تیز) means sharp, fast & active. This is a simple, to-the-point, library to make your pytorch training easy.

_This library is in early-stage currently! So, there might be breaking changes._

### Idea around tez is simple:

- keep things as simple as possible
- make it as customizable as possible
- clean code
- faster prototyping
- production ready

Currently, tez supports cpu, single gpu and multi-gpu training. More coming soon!

Using tez is super-easy. We don't want you to be far away from pytorch. So, you do everything on your own and just use tez to make a few things simpler.
